/* menuOmsl.h generated from menuOmsl.dbd */

#ifndef INC_menuOmsl_H
#define INC_menuOmsl_H

#ifndef menuOmsl_NUM_CHOICES
typedef enum {
    menuOmslsupervisory             /* supervisory */,
    menuOmslclosed_loop             /* closed_loop */
} menuOmsl;
#define menuOmsl_NUM_CHOICES 2
#endif


#endif /* INC_menuOmsl_H */
